var baseInertia = 120;

function getColorOfStrength(strength){
	if(strength > 60)
		return "#66B3FF";
	else if(strength > 45)
		return "#00D900";
	else if(strength > 35)
		return "#DDBB00";
	else if(strength > 20)
		return "#FF6600";
	else if(strength > 0)
		return "#FF0000";
	else
		return "#000000";
}

function getColorOfSpeed(strength){
	if(strength >= 48)
		return "#66B3FF";
	else if(strength >= 36)
		return "#00D900";
	else if(strength >= 24)
		return "#DDBB00";
	else if(strength >= 12)
		return "#FF6600";
	else if(strength >= 3)
		return "#FF0000";
	else
		return "#000000";
}

function getMaskPositionForStrength(strength){
	if(strength > 60)
		return "-50px";
	else if(strength > 45)
		return "-50px";
	else if(strength > 35)
		return "-39px";
	else if(strength > 20)
		return "-30px";
	else if(strength > 0)
		return "-23px";
	else
		return "0px";
}

function getPictureOfSpeed(speed){
	if(speed == 54)
		return "images/top-speed-blue.png";
	else if(speed >= 36)
		return "images/top-speed-green.png";
	else if(speed >= 14)
		return "images/top-speed-gold.png";
	else
		return "images/top-speed-red.png";
}

function getPictureOfEncryption(crypto){
	if(crypto.indexOf("WPA2") >= 0)
		return "images/top-lock-blue.png";
	else if(crypto.indexOf("WPA") >= 0)
		return "images/top-lock-green.png";
	else if(crypto.indexOf("WEP") >= 0)
		return "images/top-lock-gold.png";
	else
		return "images/top-lock-red.png";
}


function getColorForStrength(strength){
	if(strength > 60)
		return "blue";
	else if(strength > 45)
		return "green";
	else if(strength > 35)
		return "yellow";
	else if(strength > 20)
		return "orange";
	else if(strength > 0)
		return "red";
	else
		return "gray";
}

function getEncryptionFromInt(value){
	switch(value){
		case 0:
			return "&nbsp;";
		case 1:
			return "WEP";
		case 2:
			return "WPA";
		default:
			return "&nbsp;?&nbsp;";
	}
}


function getEncryptionFromString(s){
	if(s.indexOf("WPA") >= 0)
		return 2;
	else if(s.indexOf("WEP") >= 0)
		return 1;
	else
		return 0;
	
}

function WirelessNetwork()
{
	this.ssid = " ";
	this.vendor = " ";
	this.macAddress = "00:00:00:00:00:00";
	this.signal = 0;
	this.encryption = 0;
	this.cryptoString = "";
	this.speed = 0;
	this.channel = 0;
	this.inertia = 0;
	
	this.connected = false;
}

// WirelessNetwork Refresh - returns true if network is still active - false if network is dead.
WirelessNetwork.prototype.refresh = function(){
	this.inertia -= 10;
	
	//alert(this.ssid + " " + this.inertia);
	
	if(this.inertia < 0){
		this.inertia = 0;
		return false;	
	}
	else
		return true;
}


WirelessNetwork.prototype.update = function(ssid, vendor, macAddress, signal, cryptoString, speed){
	this.ssid = ssid;
	this.vendor = vendor;
	this.macAddress = macAddress;
	this.signal = signal >= 99 ? 99 : signal;
	this.encryption = getEncryptionFromString(cryptoString);
	this.cryptoString = cryptoString;
	this.speed = speed > 0 ? speed : this.speed;
	
	
	this.inertia = this.signal + baseInertia;
	
	//alert("NETWORK INFO: "+this.ssid + " " + this.vendor);
}

WirelessNetwork.prototype.updateHTML = function(signalElement, signalImage, nameElement, vendorElement, speedElement, cryptoElement){
	nameElement.innerText = this.ssid;
	vendorElement.innerText = this.vendor;
	speedElement.style.background = "url(" + getPictureOfSpeed(this.speed) + ") no-repeat bottom left";
	//speedElement.style.background = "url(images/eights.png) no-repeat left center " +  getColorOfSpeed(this.speed);
	//speedElement.style.color = getColorOfSpeed(this.speed);
	//speedElement.innerText = this.speed;
	cryptoElement.style.background = "url(" + getPictureOfEncryption(this.cryptoString) + ") no-repeat bottom left";
	signalElement.style.background = getColorOfStrength(this.signal);
	signalImage.style.top = getMaskPositionForStrength(this.signal);

}

WirelessNetwork.connectToNetwork = function (ssid, macAddress, encryptionType){
	var networkSummary = new NetworkSummary(ssid, macAddress, encryptionType);
	networkSummary._connect();
}


WirelessNetwork.prototype.toListHTML = function(index){
	var adjustedSignal = this.signal > 99 ? 99 : this.signal;
	var openLi = index % 2 == 0 ? "						<li class=\"network-itemA\" onClick=\"WirelessNetwork.connectToNetwork('"+this.ssid+"', '"+this.macAddress+"', "+this.encryption+")\">" 
		: "						<li class=\"network-itemB\" onClick=\"WirelessNetwork.connectToNetwork('"+this.ssid+"', '"+this.macAddress+"', "+this.encryption+")\">"  ;
	var closeSpan = "							</span>";
	var closeLi = "						</li>";
	var nameDiv = "							<div class=\"network-name\">" + (this.ssid.length <= 25 ? this.ssid : this.ssid.substr(0, 22) + "...") + "</div>";
	var channelDiv = "							<div class=\"network-channel\">CH: " +this.channel + "</div>";
	var strengthDiv = "							<div class=\"network-strength\">" + (adjustedSignal > 0 ? adjustedSignal: 0) + "</div>";
	var vendorDiv = "							<div class=\"network-vendor\">" + (this.vendor.length <= 28 ? this.vendor : this.vendor.substr(0, 24) + "...") + "</div>";
	var encryptionDiv = "							<div class=\"network-encryption\">" +getEncryptionFromInt(this.encryption) + "</div>";
	var macDiv = "							<div class=\"network-mac\">" +this.macAddress + "</div>";
	var openSpan = "";
	
	if(this.connected == true){
		openSpan = "							<span class=\"active_"+getColorForStrength(this.signal)+"\">";
	}
	else{
		openSpan = "							<span class=\"connected_"+getColorForStrength(this.signal)+"\">";
	}
	

	return openLi + " \n" + openSpan + " \n" + nameDiv + " \n" + channelDiv + " \n" + strengthDiv  + " \n" + vendorDiv + " \n" + encryptionDiv  + " \n" + macDiv + " \n" + closeSpan + " \n" + closeLi;
	
}


WirelessNetwork.prototype.valueOf = function(){
	return this.signal;
}

function WirelessNetworkList()
{
	this.networks = new Array();
}

WirelessNetworkList.prototype.addNetwork = function(network){
	this.networks.push(network);
}

WirelessNetworkList.prototype.addNetworkFromArray = function(networkAsArray , isConnected){
	var network = new WirelessNetwork();
	var foundIt = false;
	
	network.ssid = networkAsArray[0];
	network.macAddress = networkAsArray[1];
	network.vendor = networkAsArray[2];
	network.channel = networkAsArray[3];
	network.signal = Math.round(networkAsArray[4] * 1.1);
	network.encryption = networkAsArray[5];
	
	network.connected = isConnected;
	
	network.inertia = network.signal + baseInertia;
	
	
	for( j=0; j<this.networks.length && !foundIt; j++){
		if (this.networks[j].macAddress.indexOf(network.macAddress) > -1){
		
			this.networks[j].ssid = network.ssid;
			this.networks[j].macAddress = network.macAddress;
			this.networks[j].vendor = network.vendor;
			this.networks[j].channel = network.channel; 
			this.networks[j].signal = network.signal;
			this.networks[j].encryption = network.encryption;

			this.networks[j].connected = network.connected;

			this.networks[j].inertia = network.inertia;		
			
			foundIt = true;
		}
	}
	
	if(!foundIt)
		this.networks.push(network);
}

WirelessNetworkList.prototype.refresh = function(){

	var tempArray = new Array();
	
	for( i=0; i<this.networks.length; i++){
		this.networks[i].signal = 0;
		if(this.networks[i].refresh()){
			tempArray.push(this.networks[i]);
		}
	}
	
	//alert(tempArray);
	
	this.networks = tempArray;
}


WirelessNetworkList.prototype.toHTML = function(){
	var openTag = "					<ul class=\"network-content\">\n";
	var closeTag = "					</ul>\n";
	var content = " ";
	
	for(i=0; i<this.networks.length; i++){
		content = content + " " + this.networks[i].toListHTML(i);
	}
	
	return openTag + " " + content + " " + closeTag;
}

WirelessNetworkList.prototype.sortByStrength = function(){
	this.networks.sort(compareSignal);
}

WirelessNetworkList.prototype.sortBySSID = function(){
	this.networks.sort(compareName);
}

WirelessNetworkList.prototype.sortByVendor = function(){
	this.networks.sort(compareVendor);
}

WirelessNetworkList.prototype.sortByEncryption = function(){
	this.networks.sort(compareEncryption);
}

WirelessNetworkList.prototype.sortByChannel = function(){
	this.networks.sort(compareChannel);
}


//********* COMPARISON FUCTIONS FOR SORTING THE NETWORK LIST ****************//

function compareSignal(a,b){
	return b.signal == a.signal ? compareName(a,b) : b.signal - a.signal;
}

function compareChannel(a,b){
	return a.channel - b.channel ? compareName(a,b) : a.channel - b.channel;	
}

function compareEncryption(b,a){
	if(a.encryption.toLowerCase() > b.encryption.toLowerCase())
		return 1;
	else if(a.encryption.toLowerCase() < b.encryption.toLowerCase())
		return -1;
	else
		return compareName(a,b);
}

function compareName(a,b){
	if(a.ssid.toLowerCase() > b.ssid.toLowerCase())
		return 1;
	else if(a.ssid.toLowerCase() < b.ssid.toLowerCase())
		return -1;
	else
		return compareNameNoCase(a,b);
}

function compareNameNoCase(a,b){
	if(a.ssid > b.ssid)
		return 1;
	else if(a.ssid < b.ssid)
		return -1;
	else
		return 0;
}

function compareVendor(a,b){
	if(a.vendor.toLowerCase() > b.vendor.toLowerCase())
		return 1;
	else if(a.vendor.toLowerCase() < b.vendor.toLowerCase())
		return -1;
	else
		return compareVendorNoCase(a,b)
}

function compareVendorNoCase(a,b){
	if(a.vendor > b.vendor)
		return 1;
	else if(a.vendor < b.vendor)
		return -1;
	else
		return 0;
}






